#
# spec file for package python-streamz
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-streamz
Version:        0.5.3
Release:        bp155.2.12
Summary:        Tool to build continuous data pipelines
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/python-streamz/streamz/
Source:         https://files.pythonhosted.org/packages/source/s/streamz/streamz-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
Requires:       python-toolz
Requires:       python-tornado
Requires:       python-zict
Recommends:     python-certifi
Recommends:     python-dask
Recommends:     python-dask-dataframe
Recommends:     python-dask-distributed
Recommends:     python-distributed
Recommends:     python-graphviz
Recommends:     python-networkx
Recommends:     python-pandas
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module confluent-kafka}
BuildRequires:  %{python_module dask-dataframe}
BuildRequires:  %{python_module dask-distributed}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module distributed}
BuildRequires:  %{python_module graphviz}
BuildRequires:  %{python_module networkx}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module tornado}
BuildRequires:  %{python_module zict}
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
# /SECTION
%python_subpackages

%description
Streamz helps you build pipelines to manage continuous streams of data.

%prep
%setup -q -n streamz-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm -rf build _build.*
# Tests assume 64bit numbers
%ifarch x86_64
rm -rf build _build.*
%pytest
%endif

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/streamz
%{python_sitelib}/streamz-%{version}-py*.egg-info

%changelog
* Sat Apr 25 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specific in %%files section
  * updated url
  * use %%pytest macro
- update to version 0.5.3:
  * fix some streams overwriting Stream.buffer method closes #317
  * Fixed flake8 issue and added comments to metadata tests
  * Created more elegant solution for getting the metadata out of the
    stream for tests
  * make sure collection functions emit metadata as a flat list added
    tests for metadata output
  * Use only auto.offset.reset for latest functionality; add doc links
  * Fix key error in consumer configs
  * Consider Kafka consumer configurations
  * Revert multi-kafka changes
  * Multi-kafka failover
  * Fix test for latest parameter
  * Add the latest parameter to from_kafka_batched
  * Add max_batch_size test
  * Add max_batch_size parameter to from_kafka_batched
  * Fix key tests
  * Adding keys PR code again
  * Fix collections.abc deprecation warnings
  * Added documentation for Metadata and reference counting.
  * Removed keys parameter from Kafka code and fixed Kafka tests
  * Added documentation and cleaned up reference counter code
  * Added reference counting and Kafka checkpointing
  * Add keys to from_kafka_batched doc string
  * Make extracting Kafka keys optional
  * Fix rolling aggregate test to increase coverage
  * Make Kafka message key,value a dict output
  * Removing deprecated usage of renaming columns with agg()
  * Fix pandas warning for deprecated usage of pd.DatetimeIndex
  * Correctly forming key, value tuples for Kafka messages
  * Update Kafka tests to incorporate message key
  * Read key along with value for messages from Kafka
  * Add reference to cuDF DataFrames support
  * Update links to rst format
  * Add reference to cuDF DataFrames support
  * Update dataframes.rst
  * STREAMZ-293: Added vscode to list of gitignore directories. This
    closes# 293
  * Update core.rst
  * Update core.py
  * Configured Travis CI to use the new conda environment file instead
    of manually installing them. Also added a few more dependencies to
    the environment file that were missed
  * Removed cython from conda environment file as it was left their by
    mistake
  * Added docs requirements to conda environment file
  * Added base Conda environment yml file
  * fix networkx error
  * add installation docs
  * fix stale docstring in `streamz.unique`.
  * Remove cudf tests, since they would now live to
    RAPIDS/cudf/custreamz.
  * Fix directory structure for checkpointing (2)
  * Added cleanup of old checkpoints
  * Add directory structure for checkpointing
  * Checkpointing feature added
  * Add groupby aggregate tests, along with a few additons for cudf
    integration for SDFs
  * Update build status image url in readme
  * update url in setup
* Fri Sep 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.2
  * Remove unwanted Dask Dataframe test in dataframe utils tests.
  * cudf tests for rolling aggregations
  * More flexible _ipython_display_
  * use _remove_downstream for slice
  * add docs and fix buffered nodes
  * FIX: connect doesn't break zip now
  * proper link for spark streaming
  * handle unique maxsize properly
  * add history test and change history to maxsize
  * use hashable kwarg
  * allow non hashable data to be used in unique
  * Remove xfail for a rolling test.
- Drop python2 support due to dependencies dropping python2 support
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
